/*
 * File Selection - A java utility to browse and manipulate sets of files.
 * Copyright (C) 2005  David I. Bell
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package fileselection;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.NoSuchElementException;


/**
 * An iterator for the FileInfoTable.
 */
public class FileInfoIterator implements Iterator
{
	/**
	 * The raw array of file info objects.
	 */
	private ArrayList mArray;

	/**
	 * The current index into the array.
	 */
	private int mIndex;


	/**
	 * Constructor which accepts the FileInfoTableModel ArrayList.
	 */
	public FileInfoIterator(ArrayList fileInfoArrayList)
	{
		mArray = fileInfoArrayList;
	}


	/**
	 * Return whether there is another file info.
	 */
	public boolean hasNext()
	{
		return mIndex < mArray.size();
	}


	/**
	 * Return the next FileInfo entry from the table.
	 */
	public Object next()
	{
		if (mIndex >= mArray.size())
			throw new NoSuchElementException();

		return mArray.get(mIndex++);
	}


	/**
	 * Return the next FileInfo object from the table.
	 * This is the same as next, but does a cast for free.
	 */
	public FileInfo getNextFileInfo()
	{
		if (mIndex >= mArray.size())
			throw new NoSuchElementException();

		return (FileInfo) mArray.get(mIndex++);
	}


	/**
	 * Method to remove the entry just obtained.
	 * This is not allowed for this iterator.
	 */
	public void remove()
	{
		throw new UnsupportedOperationException();
	}
}
