/*
 * File Selection - A java utility to browse and manipulate sets of files.
 * Copyright (C) 2005  David I. Bell
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package fileselection.dialog;

import javax.swing.JPanel;
import javax.swing.JLabel;
import javax.swing.JTextField;
import javax.swing.JOptionPane;

import java.awt.Component;
import java.awt.BorderLayout;

import fileselection.MainWindow;

import fileselection.utilities.Utils;


/**
 * Class to build and show an option dialog that lets the user
 * enter a new select list name and description or edit the
 * properties of an existing select list.
 */
public class AddSelectListDialog
{
	/**
	 * The select list name that was entered.
	 */
	protected String mSelectListName;

	/**
	 * The select list description that was entered.
	 */
	protected String mSelectListDescription;

	/**
	 * Our parent component.
	 */
	protected Component mParent;


	/**
	 * Constructor which sets the main window and the parent component.
	 * If the parent component is null then the main window is used.
	 */
	public AddSelectListDialog(MainWindow mainWindow, Component parent)
	{
		//
		// Extract the values we need.
		//
		if (parent != null)
			mParent = parent;
		else
			mParent = mainWindow.getJFrame();
	}


	/**
	 * Show the Add Select List Dialog using the default title.
	 * Returns true if the user used the OK button.
	 * After this the select list name and description can be obtained.
	 */
	public boolean show()
	{
		return show("Add Select List", "", "");
	}


	/**
	 * Show the Add Select List Dialog using the specified title.
	 * Returns true if the user used the OK button.
	 * After this the select list name and description can be obtained.
	 */
	public boolean show(String title)
	{
		return show(title, "", "");
	}


	/**
	 * Show the Add Select List Dialog with the specified title and
	 * specified initial text for the name and description fields.
	 * Returns true if the user used the OK button.
	 * After this the select list name and description can be obtained.
	 */
	public boolean show(String title, String name, String description)
	{
		//
		// Allocate the panel holding the message.
		//
		JPanel mainPanel = new JPanel(new BorderLayout());

		//
		// Allocate the labels and fields.
		//
		JLabel nameLabel = new JLabel("Select List Name");
		JLabel descriptionLabel = new JLabel("Description");

		JTextField nameField = new JTextField(20);
		JTextField descriptionField = new JTextField(50);

		nameField.setText(name);
		descriptionField.setText(description);

		JPanel labelPanel = new JPanel(new BorderLayout());
		JPanel fieldPanel = new JPanel(new BorderLayout());

		labelPanel.add(nameLabel, BorderLayout.NORTH);
		labelPanel.add(descriptionLabel, BorderLayout.SOUTH);

		fieldPanel.add(nameField, BorderLayout.NORTH);
		fieldPanel.add(descriptionField, BorderLayout.SOUTH);

		mainPanel.add(labelPanel, BorderLayout.WEST);
		mainPanel.add(fieldPanel, BorderLayout.CENTER);

		//
		// Show the dialog and get which button was used.
		//
		int result = JOptionPane.showConfirmDialog(mParent, mainPanel,
			title, JOptionPane.OK_CANCEL_OPTION);

		//
		// If the dialog was cancelled then return false.
		//
		if (result != JOptionPane.OK_OPTION)
			return false;

		//
		// Extract the select list name and description.
		//
		mSelectListName = Utils.trimSpaces(nameField.getText());
		mSelectListDescription = Utils.trimSpaces(descriptionField.getText());

		return true;
	}


	/**
	 * Return the select list name that was entered.
	 */
	public String getSelectListName()
	{
		return mSelectListName;
	}


	/**
	 * Return the description string that was entered.
	 */
	public String getSelectListDescription()
	{
		return mSelectListDescription;
	}
}
